==> apache-jena-5.2.0.zip: org/apache/jena/rdfxml/xmlinput1/states/OuterXMLLiteral.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.jena.rdfxml.xmlinput1.states;

import org.apache.jena.rdfxml.xmlinput1.impl.ARPString;
import org.apache.jena.rdfxml.xmlinput1.impl.AbsXMLContext;
import org.xml.sax.SAXParseException;





public class OuterXMLLiteral extends AbsXMLLiteral {
    
   final String parseType;
    
    public OuterXMLLiteral(WantsObjectFrameI s, AbsXMLContext x, String pt) {
        super(s, x, new StringBuffer());
        parseType = pt;
        
    }

    @Override
    public void endElement() throws SAXParseException {
        ARPString xmlLiteral = new ARPString(this,rslt.toString(),parseType );
        if (taint.isTainted())
            xmlLiteral.taint();
        ((WantsObjectFrameI)getParent()).theObject(
                xmlLiteral
                );

        
    }



}

==> apache-jena-5.6.0.zip: org/apache/jena/rdfxml/xmlinput1/states/OuterXMLLiteral.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.jena.rdfxml.xmlinput1.states;

import org.apache.jena.rdfxml.xmlinput1.impl.ARPString;
import org.apache.jena.rdfxml.xmlinput1.impl.AbsXMLContext;
import org.xml.sax.SAXParseException;





public class OuterXMLLiteral extends AbsXMLLiteral {
    
   final String parseType;
    
    public OuterXMLLiteral(WantsObjectFrameI s, AbsXMLContext x, String pt) {
        super(s, x, new StringBuilder());
        parseType = pt;
        
    }

    @Override
    public void endElement() throws SAXParseException {
        ARPString xmlLiteral = new ARPString(this,rslt.toString(),parseType );
        if (taint.isTainted())
            xmlLiteral.taint();
        ((WantsObjectFrameI)getParent()).theObject(
                xmlLiteral
                );

        
    }



}
